/**************************************************************
	Full color LED PWM control	 for PIC10F222 (10F220 10F200)
 **************************************************************
	author air_variable
	http://www.ne.jp/asahi/air/variable/
	version: see below
	Tools:
	MPLAB v8.84
	Hitech PIC C pro v9.83 /Microchip XC8 v1.00
---------------------------------------------------------------
Date	:Time	Version	Build	Note
20100530 22:28	1.00	8.76	Begin the program
20110909 18:00	1.10	8.76	Corresponding 10F220,10F200
20110925 12:00	1.20	8.84	Correspond Hitec PICC 9.83 (WDT_OFF -> WDTE_OFF)
---------------------------------------------------------------
Project folder(default)
	C:\picsrc\piccpro\pwmled_10f222
Source Files
	main.c (This file)
Header Files
	none
---------------------------------------------------------------
Pin assignment 10F220 or 10F222
	[8 Lead Dip pin package]
	1::NC
	2:pickit2-2:VDD(+) with connect Color LED common
	3:         :GP2:O:LED ch2( must use resistor)
	4:pickit2-5:GP1:O:LED ch1( must use resistor)
	5:pickit2-4:GP0:O:LED ch0( must use resistor)
	6:         :NC
	7:pickit2-3:VSS:GND
	8:pickit2-1:MCLR/GP3:OPEN

	[6 Lead SOT-23 packeage]
	1:pickit2-4:GP0:O:LED ch0( must use resistor)
	2:pickit2-3:VSS:GND
	3:pickit2-5:GP1:O:LED ch1( must use resistor)
	4:         :GP2:O:LED ch2( must use resistor)
	5:pickit2-2:VDD(+) with connect Color LED common
	8:pickit2-1:MCLR/GP3:OPEN

note :Please set use your type of LED by #define.
  eg. use Anode common LED : #define Anode_common
      use Cathode common LED : nothing
      cathode common:connect with GND
      anode common :connect with VDD

	These are not checked by an actual 10F220 and 10F200     
**************************************************************/
#include <htc.h>
#define MHz 000000
#define _XTAL_FREQ 4MHz

//----------------------------------------------
//which type of LED-commom anode or cathode?
//#define Anode_common
//
#define PwmResolution 127
#define PwmCycleSpan 8
#define PauseSpeed 200	//x 10millisecond
//----------------------------------------------

//LED port define
#define PortLED0 GP0
#define PortLED1 GP1
#define PortLED2 GP2

//start state set
#define StartState 0

//LED type set
#if defined(Anode_common)

#define off 1
#define on 0
#else

#define off 0
#define on 1
#endif

#define PauseColor delay_10ms(PauseSpeed);

#if defined(_10F222)
__CONFIG( IOSCFS_4MHZ & MCPU_OFF & WDTE_OFF & MCLRE_OFF & CP_OFF);
#define UseWhite

#elif defined(_10F220)
__CONFIG( IOSCFS_4MHZ & MCPU_OFF & WDTE_OFF & MCLRE_OFF & CP_OFF);
#undef UseWhite

#elif defined(_10F200)
__CONFIG( OSC_IntRC & WDTE_OFF & MCLRE_OFF & CP_OFF);
#undef UseWhite

#endif

void delay_10ms(unsigned char temp){
	while(temp--){
		__delay_ms(10);
	}	
}

void main(void){
	unsigned char led0,led1,led2,state;
	led0 = PwmResolution;
	led1 = led2 = state = 0;
	
#if defined(_10F222)
	ANS1 = ANS0 = 0;//digital port set
#endif

	OPTION   = 0b11010111;
    TRISGPIO = 0b11111000;

	while (1){
		unsigned char outcnt= PwmCycleSpan;
		while(outcnt--){
			unsigned char i;
			for (i=1; i!=PwmResolution ;  i++){
				if ( led0 <= i ) PortLED0=off; else PortLED0=on;
				if ( led1 <= i ) PortLED1=off; else PortLED1=on;
				if ( led2 <= i ) PortLED2=off; else PortLED2=on;
			}
		}	

		switch (state){	
			case 0:led1++;//001->011
				if (led1 > PwmResolution ) {
					state=1;
					PauseColor;
				}
				break;
			case 1:led0--;//011->010
				if (led0 ==0) {
					state=2;
					PauseColor;
				}
				break;
			case 2:led2++;//010->110
				if (led2 > PwmResolution ) {
				 state=3;
					PauseColor;
				}
				break;
			case 3:led1--;//110->100
				if (led1 ==0) {
					state=4;
					PauseColor;
				}
				break;
			case 4:led0++;//100->101
				if (led0 > PwmResolution ) {
					state=5;
					PauseColor;
				}
				break;
			case 5:led2--;//101->001
				if (led2 ==0) {
					state=6;
					PauseColor;
				}
				break;

#if defined(UseWhite)	//white color 			
			case 6:led1++;led2++;	//001->111 going to all on
				if (led1 > PwmResolution ) {
					state=7;
					PauseColor;
				}
				break;

			case 7:led0--;;	//111->011
				if (led0 ==0) {
					state=2;
					PauseColor;
				}
				break;
#endif
			default:
				state=0;
			
		}
    }
}
